# eric7.Debugger.BreakPointViewer

Module implementing the Breakpoint viewer widget.

### Global Attributes

None

### Classes

BreakPointViewer | Class implementing the Breakpoint viewer widget.

### Functions

None

## BreakPointViewer

Class implementing the Breakpoint viewer widget.

Breakpoints will be shown with all their details. They can be modified through the context menu of this widget.

### Signals

sourceFile(str, int)
  emitted to show the source of a breakpoint

### Derived from

QTreeView

### Class Attributes

None

### Class Methods

None

### Methods

BreakPointViewer | Constructor
__addBreak | Private slot to handle the add breakpoint context menu entry.
__clearSelection | Private slot to clear the selection.
__configure | Private method to open the configuration dialog.
__createPopupMenus | Private method to generate the popup menus.
__deleteAllBreaks | Private slot to handle the delete all breakpoints context menu entry.
__deleteBreak | Private slot to handle the delete breakpoint context menu entry.
__deleteSelectedBreaks | Private slot to handle the delete selected breakpoints context menu entry.
__disableAllBreaks | Private slot to handle the disable all breakpoints context menu entry.
__disableBreak | Private slot to handle the disable breakpoint context menu entry.
__disableSelectedBreaks | Private slot to handle the disable selected breakpoints context menu entry.
__doubleClicked | Private slot to handle the double clicked signal.
__editBreak | Private slot to handle the edit breakpoint context menu entry.
__editBreakpoint | Private slot to edit a breakpoint.
__enableAllBreaks | Private slot to handle the enable all breakpoints context menu entry.
__enableBreak | Private slot to handle the enable breakpoint context menu entry.
__enableSelectedBreaks | Private slot to handle the enable selected breakpoints context menu entry.
__fromSourceIndex | Private slot to convert a source index to an index.
__getSelectedItemsCount | Private method to get the count of items selected.
__layoutDisplay | Private slot to perform a layout operation.
__loadRecent | Private method to load the recently used file names and breakpoint conditions.
__resizeColumns | Private slot to resize the view when items get added, edited or deleted.
__resort | Private slot to resort the tree.
__saveRecent | Private method to save the list of recently used file names and breakpoint conditions.
__setBpEnabled | Private method to set the enabled status of a breakpoint.
__setRowSelected | Private slot to select a complete row.
__showBackMenu | Private slot to handle the aboutToShow signal of the background menu.
__showContextMenu | Private slot to show the context menu.
__showSource | Private slot to handle the goto context menu entry.
__toSourceIndex | Private slot to convert an index to a source index.
clearHistories | Public method to clear the recently used file names and breakpoint conditions.
handleResetUI | Public slot to reset the breakpoint viewer.
highlightBreakpoint | Public slot to handle the clientLine signal.
setModel | Public slot to set the breakpoint model.

### Static Methods

None

#### BreakPointViewer (Constructor)

BreakPointViewer(parent=None)

Constructor

parent
  the parent (QWidget)

#### BreakPointViewer.__addBreak

__addBreak()

Private slot to handle the add breakpoint context menu entry.

#### BreakPointViewer.__clearSelection

__clearSelection()

Private slot to clear the selection.

#### BreakPointViewer.__configure

__configure()

Private method to open the configuration dialog.

#### BreakPointViewer.__createPopupMenus

__createPopupMenus()

Private method to generate the popup menus.

#### BreakPointViewer.__deleteAllBreaks

__deleteAllBreaks()

Private slot to handle the delete all breakpoints context menu entry.

#### BreakPointViewer.__deleteBreak

__deleteBreak()

Private slot to handle the delete breakpoint context menu entry.

#### BreakPointViewer.__deleteSelectedBreaks

__deleteSelectedBreaks()

Private slot to handle the delete selected breakpoints context menu entry.

#### BreakPointViewer.__disableAllBreaks

__disableAllBreaks()

Private slot to handle the disable all breakpoints context menu entry.

#### BreakPointViewer.__disableBreak

__disableBreak()

Private slot to handle the disable breakpoint context menu entry.

#### BreakPointViewer.__disableSelectedBreaks

__disableSelectedBreaks()

Private slot to handle the disable selected breakpoints context menu entry.

#### BreakPointViewer.__doubleClicked

__doubleClicked(index)

Private slot to handle the double clicked signal.

index (QModelIndex)
  index of the entry that was double clicked

#### BreakPointViewer.__editBreak

__editBreak()

Private slot to handle the edit breakpoint context menu entry.

#### BreakPointViewer.__editBreakpoint

__editBreakpoint(index)

Private slot to edit a breakpoint.

index (QModelIndex)
  index of breakpoint to be edited

#### BreakPointViewer.__enableAllBreaks

__enableAllBreaks()

Private slot to handle the enable all breakpoints context menu entry.

#### BreakPointViewer.__enableBreak

__enableBreak()

Private slot to handle the enable breakpoint context menu entry.

#### BreakPointViewer.__enableSelectedBreaks

__enableSelectedBreaks()

Private slot to handle the enable selected breakpoints context menu entry.

#### BreakPointViewer.__fromSourceIndex

__fromSourceIndex(sindex)

Private slot to convert a source index to an index.

sindex (QModelIndex)
  source index to be converted

Return:
  mapped index

Return Type:
  QModelIndex

#### BreakPointViewer.__getSelectedItemsCount

__getSelectedItemsCount()

Private method to get the count of items selected.

Return:
  count of items selected

Return Type:
  int

#### BreakPointViewer.__layoutDisplay

__layoutDisplay()

Private slot to perform a layout operation.

#### BreakPointViewer.__loadRecent

__loadRecent()

Private method to load the recently used file names and breakpoint conditions.

Return:
  tuple containing the recently used file names and breakpoint conditions

Return Type:
  tuple of (list of str, list of str)

#### BreakPointViewer.__resizeColumns

__resizeColumns()

Private slot to resize the view when items get added, edited or deleted.

#### BreakPointViewer.__resort

__resort()

Private slot to resort the tree.

#### BreakPointViewer.__saveRecent

__saveRecent(fnHistory, condHistory)

Private method to save the list of recently used file names and breakpoint conditions.

fnHistory (list of str)
  list of recently used file names
condHistory (list of str)
  list of recently used breakpoint conditions

#### BreakPointViewer.__setBpEnabled

__setBpEnabled(index, enabled)

Private method to set the enabled status of a breakpoint.

index (QModelIndex)
  index of breakpoint to be enabled/disabled
enabled (bool)
  flag indicating the enabled status to be set

#### BreakPointViewer.__setRowSelected

__setRowSelected(index, selected=True)

Private slot to select a complete row.

index (QModelIndex)
  index determining the row to be selected
selected (bool)
  flag indicating the action

#### BreakPointViewer.__showBackMenu

__showBackMenu()

Private slot to handle the aboutToShow signal of the background menu.

#### BreakPointViewer.__showContextMenu

__showContextMenu(coord)

Private slot to show the context menu.

coord (QPoint)
  the position of the mouse pointer

#### BreakPointViewer.__showSource

__showSource()

Private slot to handle the goto context menu entry.

#### BreakPointViewer.__toSourceIndex

__toSourceIndex(index)

Private slot to convert an index to a source index.

index (QModelIndex)
  index to be converted

Return:
  mapped index

Return Type:
  QModelIndex

#### BreakPointViewer.clearHistories

clearHistories()

Public method to clear the recently used file names and breakpoint conditions.

#### BreakPointViewer.handleResetUI

handleResetUI()

Public slot to reset the breakpoint viewer.

#### BreakPointViewer.highlightBreakpoint

highlightBreakpoint(fn, lineno)

Public slot to handle the clientLine signal.

fn (str)
  filename of the breakpoint
lineno (int)
  line number of the breakpoint

#### BreakPointViewer.setModel

setModel(model)

Public slot to set the breakpoint model.

model (BreakPointModel)
  reference to the breakpoint model

Up